@@ -92,7 +92,7 @@ class GenericConsumer(object):
         try:
             queue(self.connection).queue_declare(passive=True)
         except ChannelError, e:
-            if e.message == 404:
+            if e.message == 404 or e.reply_code == 404:
                 return False
             raise
         return True
@@ -198,7 +198,11 @@ class BugzillaConsumer(GenericConsumer):
 class SimpleBugzillaConsumer(GenericConsumer):
 
     def __init__(self, **kwargs):
-        super(SimpleBugzillaConsumer, self).__init__(PulseConfiguration(**kwargs), 'org.mozilla.exchange.bugzilla.simple', **kwargs)
+        exchange = 'org.mozilla.exchange.bugzilla.simple'
+        if kwargs.get('dev'):
+            exchange += '.dev'
+        super(SimpleBugzillaConsumer, self).__init__(PulseConfiguration(
+                **kwargs), exchange, **kwargs)
 
 
 class CodeConsumer(GenericConsumer):
